/*
 *  TOPPERS/ASP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Advanced Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *  Copyright (C) 2006-2016 by Embedded and Real-Time Systems Laboratory
 *              Graduate School of Information Science, Nagoya Univ., JAPAN
 * 
 *  上記著作権者は，以下の(1)〜(4)の条件を満たす場合に限り，本ソフトウェ
 *  ア（本ソフトウェアを改変したものを含む．以下同じ）を使用・複製・改
 *  変・再配布（以下，利用と呼ぶ）することを無償で許諾する．
 *  (1) 本ソフトウェアをソースコードの形で利用する場合には，上記の著作
 *      権表示，この利用条件および下記の無保証規定が，そのままの形でソー
 *      スコード中に含まれていること．
 *  (2) 本ソフトウェアを，ライブラリ形式など，他のソフトウェア開発に使
 *      用できる形で再配布する場合には，再配布に伴うドキュメント（利用
 *      者マニュアルなど）に，上記の著作権表示，この利用条件および下記
 *      の無保証規定を掲載すること．
 *  (3) 本ソフトウェアを，機器に組み込むなど，他のソフトウェア開発に使
 *      用できない形で再配布する場合には，次のいずれかの条件を満たすこ
 *      と．
 *    (a) 再配布に伴うドキュメント（利用者マニュアルなど）に，上記の著
 *        作権表示，この利用条件および下記の無保証規定を掲載すること．
 *    (b) 再配布の形態を，別に定める方法によって，TOPPERSプロジェクトに
 *        報告すること．
 *  (4) 本ソフトウェアの利用により直接的または間接的に生じるいかなる損
 *      害からも，上記著作権者およびTOPPERSプロジェクトを免責すること．
 *      また，本ソフトウェアのユーザまたはエンドユーザからのいかなる理
 *      由に基づく請求からも，上記著作権者およびTOPPERSプロジェクトを
 *      免責すること．
 * 
 *  本ソフトウェアは，無保証で提供されているものである．上記著作権者お
 *  よびTOPPERSプロジェクトは，本ソフトウェアに関して，特定の使用目的
 *  に対する適合性も含めて，いかなる保証も行わない．また，本ソフトウェ
 *  アの利用により直接的または間接的に生じたいかなる損害に関しても，そ
 *  の責任を負わない．
 * 
 *  $Id: xuartps.h 814 2017-07-25 05:19:11Z ertl-honda $
 */

/*
 *		XUartPS に関する定義
 */

#ifndef TOPPERS_XUARTPS_H
#define TOPPERS_XUARTPS_H

/*
 * UART Registers
 */
#define XUARTPS_CR_REG     (0x00)   /* Control Register */
#define     XUARTPS_CR_STOPBRK          0x00000100   /* Stop TX break */
#define     XUARTPS_CR_TX_EN            0x00000010   /* TX enabled */
#define     XUARTPS_CR_RX_EN            0x00000004   /* RX enabled */
#define     XUARTPS_CR_TX_DIS           0x00000020   /* TX disabled. */
#define     XUARTPS_CR_RX_DIS           0x00000008   /* RX disabled. */
#define     XUARTPS_CR_TXRST            0x00000002   /* TX logic reset */
#define     XUARTPS_CR_RXRST            0x00000001   /* RX logic reset */

#define XUARTPS_MR_REG     (0x04)   /* Mode Register */
#define     XUARTPS_MR_STOPMODE_1_BIT   0x00000000   /* 1 stop bit */
#define     XUARTPS_MR_PARITY_NONE      0x00000020   /* No parity mode */
#define     XUARTPS_MR_CHARLEN_8_BIT    0x00000000   /* 8 bits data */
#define     XUARTPS_MR_CLKSEL           0x00000001   /* Input clock select */
#define     XUARTPS_MR_CCLK             0x00000400   /* Input clock select */

#define XUARTPS_IER_REG    (0x08)   /* Interrupt Enable */
#define XUARTPS_IDR_REG    (0x0C)   /* Interrupt Disable */
#define XUARTPS_ISR_REG    (0x14)   /* Interrupt Status */
#define    XUARTPS_IXR_TXEMPTY          0x00000008   /* TX FIFO empty int */
#define    XUARTPS_IXR_RXTRIG           0x00000001   /* RX FIFO trigger int */

#define XUARTPS_BAUDGEN_REG (0x18)  /* Baud Rate Generator */
#define XUARTPS_BAUDDIV_REG (0x34)  /* Baud Rate Divider */

#define XUARTPS_RXTOUT_REG  (0x1C)  /* RX Timeout [7:0] */

#define XUARTPS_SR_REG      (0x2C)  /* Channel Status */
#define         XUARTPS_SR_TXFULL       0x00000010   /* TX FIFO full */
#define         XUARTPS_SR_RXEMPTY      0x00000002   /* RX FIFO empty */

#define XUARTPS_FIFO_REG    (0x30)  /* FIFO */
#define XUARTPS_RXWM_REG    (0x20)  /* RX FIFO Trigger */

#endif /* TOPPERS_XUARTPS_H */
